@@ -25,7 +25,7 @@ class Cloud(object):
     def __setstate__(self, state):
         self.f = Husky.loads(state) 
 
-kvstore = KVStore(config.host, "CachedData")
+kvstore = KVStore(config.host, "CachedData", serialize=True, interval=0.01)
 
 class CachedData(object):
     def __init__(self, var):
